SignalRouterWidget | django_cradmin API Document

    import SignalRouterWidget from 'django_cradmin/scripts/django_cradmin/widgets/SignalRouterWidget.js'

public class | source

# SignalRouterWidget

#### Extends:

ievv_jsbase/widget/AbstractWidget~AbstractWidget → SignalRouterWidget

## Constructor Summary

Public Constructor
public | constructor(element: *, widgetInstanceId: *) |

## Member Summary

Public Members
public | logger: * |
public | signalMap: * |

## Method Summary

Public Methods
public | destroy() |
public | getDefaultConfig(): * |
public | initializeSignalHandlers() |

## Public Constructors

### public constructor(element: *, widgetInstanceId: *) source

#### Params:

Name | Type | Attribute | Description
element | * |  |
widgetInstanceId | * |  |

## Public Members

### public logger: * source

### public signalMap: * source

## Public Methods

### public destroy() source

### public getDefaultConfig(): * source

#### Return:

*

### public initializeSignalHandlers() source